@@ -1,9 +1,12 @@
 import bybit
 #
-client = bybit.bybit(test=False, api_key="LVaw7yxFRZUU1IH8kv", api_secret="CDsT3G0eDGrZlqPmPw8WhpNvdjy3D61ztY1E")
+client = bybit.bybit(test=True, api_key="", api_secret="")
 #
 # # # Get server time
-# print(client.Common.Common_get().result()[0])
+# print(client.Common.Common_getTime().result()[0])
+
+# # # Get api announcement
+# print(client.Common.Common_announcements().result()[0])
 #
 # # # Get Symbol lists
 # print(client.Symbol.Symbol_get().result()[0]["result"][0])
@@ -11,6 +14,12 @@ client = bybit.bybit(test=False, api_key="LVaw7yxFRZUU1IH8kv", api_secret="CDsT3
 # #
 # # # Get public trading lists
 # print(client.Market.Market_tradingRecords(symbol="BTCUSD").result()[0]["result"][0])
+
+# kline
+# print(client.Kline.Kline_get(symbol="BTCUSD", interval="30",limit=200, **{'from':1600544880}).result())
+#markprice kline
+# print(client.Kline.Kline_markPrice(symbol="BTCUSD", interval="30",limit=200, **{'from':1600544880}).result())
+
 # #
 # # # Change account user leverage
 # print(client.Positions.Positions_saveLeverage(symbol="BTCUSD", leverage="14").result())
@@ -19,7 +28,7 @@ client = bybit.bybit(test=False, api_key="LVaw7yxFRZUU1IH8kv", api_secret="CDsT3
 # print(client.Positions.Positions_closePnlRecords(symbol="BTCUSD").result()[0]["result"][0])
 # #
 # # # Query account positions
-print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
+# print(client.Positions.Positions_myPosition().result())
 # #
 # # #Place an Active Order
 # print(client.Order.Order_new(side="Buy",symbol="BTCUSD",order_type="Limit",qty=1,price=8300,time_in_force="GoodTillCancel").result())
@@ -31,13 +40,24 @@ print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
 # print(client.Order.Order_cancel(symbol="BTCUSD", order_id="b441f0e6-a105-46fb-af81-4beb01bdeed8").result())
 # #
 # # # Place Conditional Order
-# print(client.Conditional.Conditional_new(order_type="Limit",side="Buy",symbol="BTCUSD",qty=1,price=8100,base_price=8300,stop_px=8150,time_in_force="GoodTillCancel", order_link_id="cus_order_id_2").result())
+# print(client.Conditional.Conditional_new(order_type="Limit",side="Buy",symbol="BTCUSD",qty=1,price=16001,base_price=15700,stop_px=16000,time_in_force="GoodTillCancel", order_link_id="cus_order_id_21106").result())
 # #
+# #Get Conditional Order(real-time)
+#print(client.Conditional.Conditional_query(symbol="BTCUSD", stop_order_id="9d1d5f0e-148a-465d-9cf3-76c4b639d902").result())
+
 # # #Get Conditional Order
-# print(client.Conditional.Conditional_getOrders(stop_order_status="Untriggered").result())
+#print(client.Conditional.Conditional_getOrders(stop_order_status="Untriggered").result())
+
+
+# # #Replace conditional order
+# print(client.Conditional.Conditional_replace(symbol="BTCUSD", order_link_id="cus_order_id_21106", p_r_qty="2000").result())
+
 # #
 # # #Cancel conditional order
-# print(client.Conditional.Conditional_cancel(symbol="BTCUSD", stop_order_id="a85b7718-aba9-4a6a-be02-90502012c4b5").result())
+# print(client.Conditional.Conditional_cancel(symbol="BTCUSD", stop_order_id="9d1d5f0e-148a-465d-9cf3-76c4b639d902").result())
+
+# # #Cancel all conditional order
+# print(client.Conditional.Conditional_cancelAll(symbol="BTCUSD").result())
 # #
 # # #changeMargin
 # print(client.Positions.Positions_changeMargin(symbol="BTCUSD", margin="0.10").result())
@@ -48,6 +68,12 @@ print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
 # #
 # # #Get wallet fund records
 # print(client.Wallet.Wallet_getRecords().result())
+
+# # #Get wallet balance
+# print(client.Wallet.Wallet_getBalance(coin="BTC").result())
+
+# # #Get exchange orders
+print(client.Wallet.Wallet_exchangeOrder().result())
 # #
 # # #Get the Last Funding Rate
 # print(client.Funding.Funding_myLastFee(symbol="BTCUSD").result())
@@ -61,6 +87,9 @@ print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
 # # #Get the trade records of a order
 # print(client.Execution.Execution_getTrades(order_id="24d6c1b1-e2aa-4ef0-8d73-55b751710a0c").result())
 # #
+# # Get closed pnl
+# print(client.Execution.Execution_closed_pnl(symbol="BTCUSD").result())
+
 # # #Get Orderbook
 # print(client.Market.Market_orderbook(symbol="BTCUSD").result())
 #
@@ -80,6 +109,7 @@ print(client.Positions.Positions_myPosition(symbol="BTCUSD").result())
 # print(client.LinearConditional.LinearConditional_query(symbol="BTCUSDT",stop_order_id="eed0915f-d2e5-4e7d-9908-1c73d792c659").result())
 # print(client.LinearPositions.LinearPositions_setAutoAddMargin(symbol="BTCUSDT", side="Sell", auto_add_margin=False).result())
 # print(client.LinearPositions.LinearPositions_switchIsolated(symbol="BTCUSDT",is_isolated=True, buy_leverage=1, sell_leverage=1).result())
+# print(client.LinearPositions.LinearPositions_switchMode(symbol="BTCUSDT",tp_sl_mode="Full").result())
 # print(client.LinearPositions.LinearPositions_saveLeverage(symbol="BTCUSDT", buy_leverage=10, sell_leverage=10).result())
 # print(client.LinearPositions.LinearPositions_myPosition(symbol="BTCUSDT").result())
 # print(client.LinearPositions.LinearPositions_tradingStop(symbol="BTCUSDT", side="Buy", take_profit=10).result())
